%define ver 2.8
%define subver 67

Name: gsoap
Version: %{ver}.%{subver}
%define subrel	1
Release: %mkrel 2
Summary: Development toolkit for SOAP/XML Web services in C/C++
Group: Development/Other
License: GPLv2
Source: https://downloads.sourceforge.net/gsoap2/gsoap_%{version}.zip
Patch0: Makefile.am.patch
Patch1: gsoap-2.8.66-ssl.patch
Patch2: gsoap-2.8-automake.patch
# Backport from gsoap 2.8.105
# Included so that the following security fix applies cleanly
Patch3:		gsoap-wsse.patch
# Backport from gsoap 2.8.109
# Fixes CVE: CVE-2020-13574 CVE-2020-13575 CVE-2020-13577 CVE-2020-13578
Patch4:		gsoap-plugins-hardening.patch
# Backport from gsoap 2.8.111
# Fixes CVE: CVE-2020-13576
Patch5:		gsoap-url-parse-hardening.patch
URL: http://www.cs.fsu.edu/~engelen/soap.html
BuildRequires: automake
BuildRequires: bison
BuildRequires: libstdc++-devel
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(zlib)
BuildRequires: flex

%description
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

%package        source
Summary:        Source files of %{name}
Group:          Development/C

%description    source
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

This package contains the source code.

%prep
%setup -q -n %{name}-%{ver}
# remove pre-built binaries and libraries in source tree
rm -rf gsoap/bin

%patch0 -p0 -b .fPIC
%patch1 -p0 -b .ssl
%patch2 -p0 -b .automake
%patch3 -p1
%patch4 -p1
%patch5 -p1

# make automake more happy
sed -i -e 's,\(^AM_INIT_AUTOMAKE(\[\),\1subdir-objects ,' configure.ac

# fix build with glibc >= 2.27
sed -i -e 's,xlocale.h,locale.h,g' ./gsoap/stdsoap2.h

%build
autoreconf -vfi
%configure2_5x

# keep a copy of source code (used by some TPM tools for Intel Classmate)
rm -rf %{name}-source
cp -a . ../%{name}-source
mv ../%{name}-source .

# remove pre-built binaries and libraries in source tree
find %{name}-source -name "*.so" -exec rm {} \;
find %{name}-source -name "*.o" -exec rm {} \;
find %{name}-source -name "*.dll" -exec rm {} \;
find %{name}-source -name "*.exe" -exec rm {} \;
find %{name}-source -name "*.la" -exec rm {} \;
find %{name}-source -name "*.a" -exec rm {} \;
find %{name}-source -name "*.pdf" -exec rm {} \;
find %{name}-source -name "*.doc" -exec rm {} \;

# next files make debuginfo failing:
rm -rf %{name}-source/%{name}/ios_plugin/examples/Calc/build/Debug-iphonesimulator/Calc.app/Calc
rm -rf %{name}-source/%{name}/ios_plugin/examples/GeoIPService/build/Debug-iphonesimulator/GeoIPService.app/GeoIPService
rm -rf %{name}-source/%{name}/samples/link++/xmas
rm -rf %{name}-source/%{name}/samples/wcf/WS/DualHttp/calculator

make SOAPCPP2_IMPORTPATH="-DSOAPCPP2_IMPORT_PATH=\"\\\"%{_datadir}/%{name}/import\"\\\"" WSDL2H_IMPORTPATH="-DWSDL2H_IMPORT_PATH=\"\\\"%{_datadir}/%{name}/WS\"\\\""

%install
mkdir -p %buildroot/%_datadir/%name
cp -R %name/import %buildroot/%_datadir/%name
cp -R %name/WS %buildroot/%_datadir/%name
cp -R %name/uddi2 %buildroot/%_datadir/%name
cp %name/stdsoap2.cpp %buildroot/%_datadir/%name
cp %name/stdsoap2.c %buildroot/%_datadir/%name
%makeinstall
install -d %{buildroot}%{_prefix}/src/
cp -a %{name}-source %{buildroot}%{_prefix}/src/%{name}

%files
%doc LICENSE.txt NOTES.txt README.txt changelog.md factsheet.pdf license.pdf %name/doc
%{_bindir}/soapcpp2
%{_bindir}/wsdl2h
%{_includedir}/stdsoap2.h
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_libdir}/libgsoap++.a
%{_libdir}/libgsoap.a
%{_libdir}/libgsoapck++.a
%{_libdir}/libgsoapck.a
%{_libdir}/libgsoapssl++.a
%{_libdir}/libgsoapssl.a
%{_libdir}/pkgconfig/gsoapssl++.pc
%{_libdir}/pkgconfig/gsoapssl.pc
%{_libdir}/pkgconfig/gsoap++.pc
%{_libdir}/pkgconfig/gsoap.pc
%{_libdir}/pkgconfig/gsoapck++.pc
%{_libdir}/pkgconfig/gsoapck.pc

%files source
%{_prefix}/src/%{name}


%changelog
* Mon Jun 07 2021 daviddavid <daviddavid> 2.8.67-2.1.mga7
+ Revision: 1730064
- backport upstream fixes for CVE-2020-1357[4-8] (mga#29015)

* Sun Sep 23 2018 umeabot <umeabot> 2.8.67-2.mga7
+ Revision: 1298092
- Mageia 7 Mass Rebuild

* Thu Jun 21 2018 wally <wally> 2.8.67-1.mga7
+ Revision: 1238487
- new version 2.8.67

* Sun Apr 29 2018 anaselli <anaselli> 2.8.66-1.mga7
+ Revision: 1223616
- new version 2.8.66

* Thu Aug 03 2017 guillomovitch <guillomovitch> 2.8.49-2.mga7
+ Revision: 1134279
- rebuild for latest openssl

* Fri Jul 21 2017 anaselli <anaselli> 2.8.49-1.mga7
+ Revision: 1126265
- new version 2.8.49

* Fri Aug 12 2016 anaselli <anaselli> 2.8.33-1.mga6
+ Revision: 1046040
- new gsoap 2.8.33

* Mon Apr 11 2016 anaselli <anaselli> 2.8.30-1.mga6
+ Revision: 1000242
- new version

* Wed Mar 02 2016 umeabot <umeabot> 2.8.23-3.mga6
+ Revision: 983444
- Rebuild for openssl

* Thu Feb 11 2016 umeabot <umeabot> 2.8.23-2.mga6
+ Revision: 954198
- Mageia 6 Mass Rebuild

* Thu Oct 01 2015 anaselli <anaselli> 2.8.23-1.mga6
+ Revision: 885515
- New version 2.8.23

* Wed Oct 15 2014 umeabot <umeabot> 2.8.18-3.mga5
+ Revision: 741104
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.8.18-2.mga5
+ Revision: 679965
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 anaselli <anaselli> 2.8.18-1.mga5
+ Revision: 674321
- new version 2.8.18

* Fri Apr 18 2014 anaselli <anaselli> 2.8.17-1.mga5
+ Revision: 616873
- new version 2.8.17

* Mon Oct 21 2013 umeabot <umeabot> 2.8.16-2.mga4
+ Revision: 537938
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 anaselli <anaselli> 2.8.16-1.mga4
+ Revision: 488056
- New version 2.8.16

* Wed Jun 26 2013 anaselli <anaselli> 2.8.15-1.mga4
+ Revision: 447312
- New bug fixing version 1.8.15

* Thu Jan 17 2013 anaselli <anaselli> 2.8.12-2.mga3
+ Revision: 389214
- applied barjac changes, to remove other binary files
- removed useless binaries into source package
- new GPLv2 version 2.8.12
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 cjw <cjw> 2.7.17-2.mga3
+ Revision: 339120
- patch2: fix build with automake 1.13
- remove pre-built binaries from unpacked source tree

* Tue Jan 18 2011 ahmad <ahmad> 2.7.17-1.mga1
+ Revision: 21919
- imported package gsoap


* Fri Sep 17 2010 Angelo Naselli <anaselli@mandriva.org> 2.7.17-1mdv2011.0
+ Revision: 579205
- New version 2.7.17

* Thu Apr 15 2010 Angelo Naselli <anaselli@mandriva.org> 2.7.16-1mdv2010.1
+ Revision: 535062
- new version 2.7.16

* Thu Apr 08 2010 Eugeni Dodonov <eugeni@mandriva.com> 2.7.15-3mdv2010.1
+ Revision: 533161
- P2: build properly with new openssl 1.0.0.

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 2.7.15-2mdv2010.1
+ Revision: 511571
- rebuilt against openssl-0.9.8m

* Fri Nov 20 2009 Angelo Naselli <anaselli@mandriva.org> 2.7.15-1mdv2010.1
+ Revision: 467734
- new version 2.7.15

* Wed Sep 09 2009 Angelo Naselli <anaselli@mandriva.org> 2.7.14-1mdv2010.0
+ Revision: 435055
- New version 2.7.14

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.7.13-2mdv2010.0
+ Revision: 425050
- rebuild

* Sun Mar 22 2009 Angelo Naselli <anaselli@mandriva.org> 2.7.13-1mdv2009.1
+ Revision: 360085
- new version 2.7.13

* Wed Feb 04 2009 Olivier Blin <oblin@mandriva.com> 2.7.12-2mdv2009.1
+ Revision: 337458
- add gsoap-source package (to be used by some TPM tools for Intel Classmate)
- fix fprintf with no string literal (sourceforce request #2564094)

* Thu Oct 23 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.12-1mdv2009.1
+ Revision: 296729
- new version 2.7.12

* Thu Oct 23 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.11-3mdv2009.1
+ Revision: 296716
- Added -fPIC option to use it on x86_64

* Wed Jul 30 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.11-2mdv2009.0
+ Revision: 254911
- Updated with a new upstream tarball

* Mon Jul 28 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.11-1mdv2009.0
+ Revision: 251135
- New version 2.7.11

* Thu Jun 26 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.10-3mdv2009.0
+ Revision: 229303
- Fixed Url

* Thu Jun 26 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.10-2mdv2009.0
+ Revision: 229282
- Fixed bug #41665: gsoap is looking for file in rpm build environnement
- Moved WS and import under /usr/share/gsoap

* Tue Jan 29 2008 Angelo Naselli <anaselli@mandriva.org> 2.7.10-1mdv2008.1
+ Revision: 159685
- New version 2.7.10

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 12 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9l-1mdv2008.1
+ Revision: 108262
- new version 2.7.9l

* Tue Aug 28 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9k-1mdv2008.0
+ Revision: 72614
- new version 2.7.9k

* Wed Aug 01 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9j-1mdv2008.0
+ Revision: 57285
- New version 2.7.9j

* Thu Jul 12 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9i-1mdv2008.0
+ Revision: 51688
- New version 2.7.9i

* Mon Jul 02 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9h-1mdv2008.0
+ Revision: 47086
- New version 2.7.9h

* Fri Apr 27 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9f-1mdv2008.0
+ Revision: 18630
- New version 2.7.9f

* Wed Apr 18 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9e-1mdv2008.0
+ Revision: 14846
- new version 2.7.9e


* Thu Feb 22 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9d-1mdv2007.0
+ Revision: 124663
- New version 2.7.9d

* Mon Feb 12 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9c-1mdv2007.1
+ Revision: 118889
- new version 2.7.9c

* Mon Jan 01 2007 Angelo Naselli <anaselli@mandriva.org> 2.7.9b-1mdv2007.1
+ Revision: 103023
- new version 2.7.9b

* Thu Dec 07 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.9a-2mdv2007.1
+ Revision: 91930
- rebuilt
- new version 2.7.9a

* Sun Nov 05 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.9-1mdv2007.1
+ Revision: 76740
- new version 2.7.9
- Import gsoap

* Sun Jun 25 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.8c-1mdv2007.0
- New release 2.7.8c

* Mon Jun 19 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.8b-1mdv2007.0
- New release 2.7.8b

* Mon Jun 12 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.8a-1mdv2007.0
- New release 2.7.8a

* Wed Jun 07 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.8-1mdv2007.0
- New release 2.7.8

* Mon Apr 10 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.7-1mdk
- New release 2.7.7

* Tue Mar 21 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.6e-2mdk
- added import directory and typemap.dat sample files needed by tool staff

* Sun Feb 19 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.6e-1mdk
- New release 2.7.6e

* Mon Jan 09 2006 Angelo Naselli <anaselli@mandriva.org> 2.7.6d-1mdk
- New release 2.7.6d

* Thu Nov 03 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.7.6c-2mdk
- Fix BuildRequires

* Fri Oct 21 2005 Angelo Naselli <anaselli@mandriva.org> 2.7.6c-1mdk
- bilt new version for mandriva (followed a connectiva pacakge)

